@@ -5,10 +5,10 @@ import requests
 import sys
 import urlparse
 import webbrowser
-import yaml
 import re
 from os.path import join, expanduser, abspath, isfile
 
+import yaml
 from tutum.api import auth
 from tutum.api import exceptions
 import tutum
@@ -244,6 +244,22 @@ def terminate(identifiers):
             print e
 
 
+def redeploy(identifiers, tag):
+    for identifier in identifiers:
+        try:
+            is_remote, is_app, app_or_container = utils.launch_queries_in_parallel(identifier)
+            if is_remote:
+                if is_app:
+                    result = app_or_container.redeploy(tag)
+                    if result:
+                        print app_or_container.uuid
+                else:
+                    print 'The identifier provided is not an application'
+        except Exception as e:
+             print e
+
+
+
 def logs(identifiers):
     for identifier in identifiers:
         try:
@@ -323,7 +339,7 @@ def app_alias(identifiers, dns):
 
 
 def app_run(image, name, container_size, target_num_containers, run_command, entrypoint, container_ports,
-            container_envvars, linked_to_applications, autorestart, autoreplace, autodestroy, roles, local):
+            container_envvars, linked_to_applications, autorestart, autoreplace, autodestroy, roles, local, parallel):
     try:
         ports = utils.parse_ports(container_ports)
         envvars = utils.parse_envvars(container_envvars)
@@ -363,7 +379,7 @@ def app_run(image, name, container_size, target_num_containers, run_command, ent
                                            entrypoint=entrypoint, container_ports=ports,
                                            container_envvars=envvars, linked_to_application=linked_to_applications,
                                            autorestart=autorestart, autoreplace=autoreplace, autodestroy=autodestroy,
-                                           roles=roles)
+                                           roles=roles, parallel_deployment=parallel)
             result = app.save()
             if result:
                 print app.uuid
@@ -490,7 +506,7 @@ def build(image_name, working_directory, quiet, nocache):
             utils.build_dockerfile(dockerfile_path, ports, cmd)
 
         docker_client = utils.get_docker_client()
-        output = docker_client.build(path=directory, tag=image_name, quiet=quiet, nocache=nocache, rm=True)
+        output = docker_client.build(path=directory, tag=image_name, quiet=quiet, nocache=nocache, rm=True, stream=True)
         for line in output:
             if not quiet:
                 utils.print_stream_line(line)
@@ -530,7 +546,13 @@ def images(quiet=False, jumpstarts=False, linux=False, local=False, remote=False
 
         if not remote and not (linux or jumpstarts):
             headers = ["NAME", "ID", "CREATED", "PARENT ID", "VIRTUAL SIZE", "SIZE"]
-            docker_client = utils.get_docker_client()
+            try:
+                docker_client = utils.get_docker_client()
+            except DockerNotFound:
+                if local:
+                    sys.exit(EXCEPTION_EXIT_CODE)
+                else:
+                    sys.exit()
             local_images = docker_client.images(quiet=quiet)
             data_list = []
 
@@ -596,52 +618,13 @@ def update_image(repositories, username, password, description):
         except Exception as e:
             print e
 
+
 def push(name, public):
 
     AUTH_ERROR = 'auth_error'
     NO_ERROR = 'no_error'
 
-    def print_stream_line(output):
 
-        if "}{" in output:
-            lines = output.replace('}{', '}}{{').split('}{')
-        else:
-            lines = [output]
-        last_id = None
-        for line in lines:
-            formatted_output = ''
-            try:
-                obj = json.loads(line)
-                status = obj.get('status', None)
-                id = obj.get('id', None)
-                progress = obj.get('progress', None)
-                error = obj.get('error',None)
-
-                if error:
-                    print ''
-                    print error
-                    sys.exit(EXCEPTION_EXIT_CODE)
-
-                if status and id and progress:
-                    if id != last_id:
-                        formatted_output = '\n%s: %s %s' % (id, status, progress)
-                    else:
-                        formatted_output = '\r%s: %s %s\033[K' % (id, status, progress)
-
-                elif status and id:
-                    if id != last_id:
-                        formatted_output = '\n%s: %s' % (id, status)
-                    else:
-                        formatted_output = '\r%s: %s\033[K' % (id, status)
-                else:
-                    formatted_output = '\n%s' % status
-            except ValueError:
-                print line
-                sys.exit(EXCEPTION_EXIT_CODE)
-            last_id = id
-
-            sys.stdout.write(formatted_output)
-            sys.stdout.flush()
 
     def push_to_public(repository):
         print 'Pushing %s to public registry ...' % repository
@@ -652,7 +635,7 @@ def push(name, public):
             if 'status 401' in line.lower():
                 output_status = AUTH_ERROR
                 continue
-            print_stream_line(line)
+            utils.print_stream_line(line)
 
         if output_status == NO_ERROR:
             print ''
@@ -700,7 +683,7 @@ def push(name, public):
 
         output_stream = docker_client.push(repository, stream=True)
         for line in output_stream:
-            print_stream_line(line)
+            utils.print_stream_line(line)
         print ''
 
     docker_client = utils.get_docker_client()
@@ -708,3 +691,25 @@ def push(name, public):
         push_to_public(name)
     else:
         push_to_tutum(name)
+
+
+def change_app_setting(autorestart,autoreplace, autodestroy, identifiers):
+    exception = False
+
+    for identifier in identifiers:
+        try:
+            app_details = utils.fetch_remote_app(identifier, raise_exceptions=True)
+            if app_details is not None:
+                app_details.autorestart = autorestart
+                app_details.autoreplace = autoreplace
+                app_details.autodestroy = autodestroy
+                result = app_details.save()
+                if result:
+                    print app_details.uuid
+        except Exception as e:
+            print e
+            exception = True
+            continue
+
+    if exception:
+        sys.exit(EXCEPTION_EXIT_CODE)
