@@ -7,7 +7,7 @@ from tutumcli import parsers
 from tutumcli import commands
 
 
-VERSION = "0.7.3.1"
+VERSION = "0.7.3.2"
 
 sys.stdout = codecs.getwriter('utf8')(sys.stdout)
 
@@ -60,6 +60,8 @@ def main():
         commands.logs(args.identifier)
     elif args.command == "scale":
         commands.app_scale(args.identifier, args.target_num_containers)
+    elif args.command == 'redeploy':
+        commands.redeploy(args.identifier, args.tag)
     elif args.command == "alias":
         commands.app_alias(args.identifier, args.dns)
     elif args.command == "run":
@@ -68,7 +70,8 @@ def main():
                          entrypoint=args.entrypoint, container_ports=args.port,
                          container_envvars=args.env,
                          linked_to_applications=args.link, autorestart=args.autorestart,
-                         autoreplace=args.autoreplace, autodestroy=args.autodestroy, roles=args.role, local=args.local)
+                         autoreplace=args.autoreplace, autodestroy=args.autodestroy, roles=args.role, local=args.local,
+                         parallel=args.parallel)
     elif args.command == "ps":
         commands.ps(args.identifier, args.quiet, args.status, args.remote, args.local)
     elif args.command == "build":
@@ -83,6 +86,8 @@ def main():
         commands.update_image(args.repository, args.username, args.password, args.description)
     elif args.command == "push":
         commands.push(args.name, args.public)
+    elif args.command == "set":
+        commands.change_app_setting(args.autorestart, args.autoreplace, args.autodestroy, args.identifier)
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
