@@ -2,6 +2,7 @@ import datetime
 import re
 import multiprocessing
 import json
+import sys
 
 from tabulate import tabulate
 import tutum
@@ -16,11 +17,11 @@ TUTUM_LOCAL_PREFIX = "local-"
 TUTUM_LOCAL_CONTAINER_NAME = TUTUM_LOCAL_PREFIX + "%s"
 
 CONTAINER_SIZE = {
-        "XS": {"cpu_shares": 256, "memory": 268435456},
-        "S": {"cpu_shares": 512, "memory": 536870912},
-        "M": {"cpu_shares": 1024, "memory": 1073741824},
-        "L": {"cpu_shares": 2048, "memory": 2147483648},
-        "XL": {"cpu_shares": 4096, "memory": 4294967286}
+        "XS": {"memory": 268435456},
+        "S": {"memory": 536870912},
+        "M": {"memory": 1073741824},
+        "L": {"memory": 2147483648},
+        "XL": {"memory": 4294967286}
 }
 
 
@@ -311,15 +312,15 @@ def get_current_apps_and_its_containers():
     for container in stopped_running_containers:
         inspected_container = docker_client.inspect_container(container["Id"])
         app_name = get_app_name_from_container_name(inspected_container['Name'][1:])
-        size_by_cpu = get_size_from_cpu_shares(inspected_container["Config"]["CpuShares"])
+
         size_by_memory = get_size_from_memory(inspected_container["Config"]["Memory"])
 
-        if not app_name or not size_by_cpu or not size_by_memory or size_by_cpu != size_by_memory:
+        if not app_name or not size_by_memory :
             #it is not a tutum container
             continue
         app_config = current_apps.get(app_name, {"uuid": "", "status": "",
                                                  "image": inspected_container["Config"]["Image"],
-                                                 "container_size": size_by_cpu,
+                                                 "container_size": size_by_memory,
                                                  "deployed": "",
                                                  "web_hostname": "", "containers": []})
 
@@ -335,7 +336,7 @@ def get_current_apps_and_its_containers():
                             if inspected_container["Config"]["Cmd"] else "",
                             "entrypoint": " ".join(inspected_container["Config"]["Entrypoint"])
                             if inspected_container["Config"]["Entrypoint"] else "",
-                            "size": size_by_cpu,
+                            "size": size_by_memory,
                             "exit_code": inspected_container["State"]["ExitCode"],
                             "envvars": inspected_container["Config"]["Env"],
                             "deployed": datetime.datetime.strptime(inspected_container["Created"].split(".")[0],
@@ -375,14 +376,6 @@ def get_app_name_from_container_name(container_local_name):
         return "-".join(split_name[:-1])
     return None
 
-
-def get_size_from_cpu_shares(cpu_shares_value):
-    for size, config in CONTAINER_SIZE.iteritems():
-        if config["cpu_shares"] == cpu_shares_value:
-            return size
-    return None
-
-
 def get_size_from_memory(memory_value):
     for size, config in CONTAINER_SIZE.iteritems():
         if config["memory"] == memory_value:
@@ -529,7 +522,6 @@ def create_containers_for_an_app(image, tag, container_names, run_command, entry
                                                               port["protocol"]) for port in ports],
                                                       environment=env_vars,
                                                       mem_limit=CONTAINER_SIZE[container_size]["memory"],
-                                                      cpu_shares=CONTAINER_SIZE[container_size]["cpu_shares"],
                                                       name=container_names[i])
         docker_client.start(container_id["Id"],
                             links=already_deployed,
@@ -586,17 +578,6 @@ def build_dockerfile(filepath, ports, command):
                 dockerfile.write(line)
 
 
-def print_stream_line(line):
-    dict_or_tuple = eval(line.replace("}{", "},{"))
-    if isinstance(dict_or_tuple, dict):
-        dict_or_tuple = (dict_or_tuple, )
-    for message in dict_or_tuple:
-        string = ""
-        for key in message.keys():
-            string += str(message[key]).replace("\n", "")
-        print string.encode('utf8')
-
-
 class JsonDatetimeEncoder(json.JSONEncoder):
 
     def default(self, obj):
@@ -604,3 +585,48 @@ class JsonDatetimeEncoder(json.JSONEncoder):
             return str(obj)
 
         return json.JSONEncoder.default(self, obj)
+
+
+def print_stream_line(output):
+    from tutumcli.commands import EXCEPTION_EXIT_CODE
+    if "}{" in output:
+        lines = output.replace('}{', '}}{{').split('}{')
+    else:
+        lines = [output]
+    print_stream_line.last_id = None
+    for line in lines:
+        formatted_output = ''
+        try:
+            obj = json.loads(line)
+            status = obj.get('status', None)
+            id = obj.get('id', None)
+            progress = obj.get('progress', None)
+            error = obj.get('error', None)
+
+            if error:
+                print ''
+                print error
+                sys.exit(EXCEPTION_EXIT_CODE)
+
+            if status and id and progress:
+                if id != print_stream_line.last_id:
+                    formatted_output = '\n%s: %s %s' % (id, status, progress)
+                else:
+                    formatted_output = '\r%s: %s %s\033[K' % (id, status, progress)
+                print_stream_line.last_id = id
+            elif status and id:
+                if id != print_stream_line.last_id:
+                    formatted_output = '\n%s: %s' % (id, status)
+                else:
+                    formatted_output = '\r%s: %s\033[K' % (id, status)
+                print_stream_line.last_id = id
+            elif status:
+                formatted_output = '\n%s' % status
+            else:
+                for key in obj.keys():
+                    formatted_output = '%s' % obj.get(key, '')
+        except ValueError:
+            sys.stdout.write(line)
+
+        sys.stdout.write(formatted_output)
+        sys.stdout.flush()
\ No newline at end of file
